data<- read.csv("PlantResponses.csv", header = TRUE, sep = ",")
data
summary(data)
library(ggplot2)
library(plotrix)
library(dplyr)
library(gridExtra)
library(cowplot)
library(grid)
library(Rmisc)
library(lemon)
library(ggpubr)

##Plotting Root biomass##
data$Competition<- factor(data$Competition, levels = c('Without', 'With'))
data$Treatment<- factor(data$Treatment, levels = c('LN-LP', 'LN-HP', 'HN-LP', 'HN-HP'))
labels <- c(Without = "Without Competition", With = "With Competition")
RootDryMass<- ggplot(data, aes(x = Treatment, y = RootDrymass, color = Competition))+
  geom_point(position = position_dodge(0.4), size= 1.5, alpha=.4)+
  stat_summary(fun.y = 'mean', geom = 'point',position = position_dodge(0.4), size= 3)+
  stat_summary(fun.data = mean_se, geom = "errorbar", width = .1)+
  facet_rep_grid(~Competition, labeller = labeller(Competition = labels))+
  theme_classic()+
  scale_color_manual(values = c("yellowgreen", "darkgreen"))+
  theme(strip.background=element_rect(fill=NA, color=NA),
        strip.text=element_text(size=12))+
  ylab(expression("Root biomass (g " ~ plant^-1 *")"))+
  xlab("")+
  theme(legend.position = "none",legend.text = element_text(size = 10))+
  theme(axis.text.x = element_text(size = 8, colour = "black",angle = 90,vjust = 0.5), 
        axis.text.y = element_text(size = 8, color = "grey40"),
        axis.title.y = element_text(size = 9))
RootDryMass

###Stats for root biomass###
library(multcomp)
library(lsmeans)
##shoot####
m1 <- lm(RootDrymass ~ Treatment*Competition , data=data)
plot(fitted(m1), resid(m1), xlab="Fitted values", ylab="Residuals"); abline(h=0, lty=3) ##homogeneity of variance
anova(m1)
summary(m1)

####NOTE#### --> We used the same plotting and statistical approach for Shoot dry biomass, root mass fraction, shoot N and P concentration, and shoot N:P ratio



###Correlation analysis###
library(smatr)
m1<- sma(ShootNconc~SpecificRootLength*Competition, data=data, log = "")
summary(m1)
data$color<-NA
data$color[data$Competition=="With"]<-"darkgreen"
data$color[data$Competition=="Without"]<-"yellowgreen"
p<-plot(data$SpecificRootLength, data$ShootNconc, pch=19, col= data$color, xlab=expression("Specific root length (m " ~ g^-1 *")"),
        ylab = expression("Shoot N (mg " ~ g^-1 *")"), las=1)

#Plot correlation line for 'With Competition'
x<-seq(min(data$SpecificRootLength[data$Competition=="With"], na.rm=T),
       max(data$SpecificRootLength[data$Competition=="With"], na.rm=T),
       length.out=10)
y<-m1$coef$With$`coef(SMA)`[2]*x+m1$coef$With$`coef(SMA)`[1]
lines(x, y, col="darkgreen", lty=1, lwd=2)



