data<- read.csv("VerticalRootDistribution.csv", header = TRUE, sep = ",")
head(data)
library(ggplot2)
library(gridExtra)
library(cowplot)
library(dplyr)
library(plyr)
library(Rmisc)
library(lemon)

data$Treatment<-factor(data$Treatment)
data$Competition<-factor(data$Competition)
data$DepthInterval<-factor(data$DepthInterval)
data$Replicate<-as.factor(data$Replicate)

cumulative<-as.data.frame(aggregate(data$RootDrymass, by=list(Treatment=data$Treatment, Competition=data$Competition, Replicate=data$Replicate), cumsum))
cumulative[,4]<-cumulative[,4]/cumulative[,4][,6]
cumulative<-cumulative[order(cumulative$Treatment, cumulative$Competition, cumulative$Replicate),]

#CPB is cumulative proportion of root biomass

data<-data[order(data$Treatment, data$Competition, data$Replicate),]

data$CPB<-as.vector(t(cumulative[,4]))
data$d<-rep(c(10,20,30,40,50,58), 40)

results<-expand.grid(Treatment=levels(data$Treatment), Competition = levels(data$Competition), Replicate=unique(data$Replicate))
results$beta<-NA

for (i in 1:nrow(results)){
  
  sub<-data[data$Treatment==results$Treatment[i] & data$Competition==results$Competition[i] & data$Replicate==results$Replicate[i],]
  model<-nls(CPB~1-beta^d, sub, start=list(beta=1))
  results$beta[i]<-coef(model)}

results$Competition<- factor (results$Competition, levels = c('Without', 'With'))
results$Treatment <- factor(results$Treatment, levels = c("LN-LP", "LN-HP", "HN-LP", "HN-HP"))
labels <- c(Without = "Without Competition", With = "With Competition")
CPB<-ggplot(results, aes(x = Treatment, y = beta, color = Competition))+
  geom_point(position = position_dodge(0.4), size= 1.5, alpha=.4)+
  stat_summary(fun.y = 'mean', geom = 'point',position = position_dodge(0.4), size= 3)+
  stat_summary(fun.data = mean_se, geom = "errorbar", width = .1)+
  facet_rep_grid(~Competition, labeller = labeller(Competition = labels))+
  theme_classic()+
  scale_color_manual(values = c("yellowgreen", "darkgreen"))+
  theme(strip.background=element_rect(fill=NA, color=NA),
        strip.text=element_text(size=12))+
  ylab(expression(paste(beta, " (Vertical root distribution)", sep=" ")))+
  xlab("")+
  theme(legend.position = "none",legend.text = element_text(size = 10))+
  theme(axis.text.x = element_text(size = 8, colour = "black", angle = 90, vjust = 0.5), 
        axis.text.y = element_text(size = 8, color = "grey40"),
        axis.title.y = element_text(size = 9))
CPB
ann_text<- data.frame(data = results, label = c('c','', 'b','','a','','a',''),
                      x = c(1,1,2,2,3,3,4,4), 
                      y = c(0.967, 0.967, 0.967, 0.967),
                      Competition = c('Without', 'With'))
CPB1<- CPB+geom_text(data = ann_text, mapping = aes(x = x, y = y, label = label), size = 4, color ="black")
CPB1


###stats####
library(lsmeans)
library(multcomp)
CPB <- lm(beta~Treatment*Competition, data= results)
plot(fitted(CPB), resid(CPB), xlab="Fitted values", ylab="Residuals"); abline(h=0, lty=3) ##homogeneity of variance
anova(CPB)
summary(CPB)
mc<- lsmeans(CPB, pairwise~Treatment+Competition, adjust = "tukey")
mc
cld(mc)
summary(mc)

mc<- lsmeans(CPB, "Treatment", by="Competition", adjust = "tukey")
mc
summary(mc)
cld(mc)

